<?php

/**
 * @file
 * Hooks provided by the Selective Better Exposed Filters module.
 */

use Drupal\views\Plugin\views\filter\FilterPluginBase;
use Drupal\views\ViewExecutable;

/**
 * @addtogroup hooks
 * @{
 */

/**
 * Alter the supported plugins list for Selective Better Exposed Filters functionality.
 *
 * @param array<string> $ids
 *   The supported filter plugin ID's.
 */
function hook_selective_better_exposed_filters_supported_plugins_alter(array &$ids): void {
  $ids[] = 'search_api_options';
}

/**
 * Alter the target field ID according to filter plugin and view.
 *
 * @param ?string $field_id
 *   The target field ID.
 * @param \Drupal\views\ViewExecutable $view
 *   The current view.
 * @param \Drupal\views\Plugin\views\filter\FilterPluginBase $filter
 *   The target filter.
 */
function hook_selective_better_exposed_filters_field_id_alter(?string &$field_id, ViewExecutable $view, FilterPluginBase $filter) {
  $query = $view->getQuery();
  if (!$query || !method_exists('getIndex', $query)) {
    return;
  }

  $index = $query->getIndex();
  if (!$index || !method_exists('getFields', $index)) {
    return;
  }

  $index_fields = $index->getFields();
  if (empty($index_fields[$field_id])) {
    return;
  }
  $field_id = $index_fields[$field_id]->getPropertyPath();
}

/**
 * @} End of "addtogroup hooks".
 */
